==> mutual_credit-5.0.12.tar.gz: mutual_credit/modules/limits/src/Form/NotificationTemplatesForm.php <==
<?php

namespace Drupal\mcapi_limits\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
Use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\Core\Database\Connection;

/**
 * Form constructor for setting a wallet's limits.
 */
class NotificationTemplatesForm extends ConfigFormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'limit_notification_templates_form';
  }

  public function getEditableConfigNames() {
    return ['mcapi_limits.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('mcapi_limits.settings');
    $form['warning_threshhold'] = [
      '#title' => $this->t('Warning threshhold'),
      '#description' => $this->t('Fraction of the total limit to be reached before triggering a warning. Set to 0 for no warnings.'),
      '#type' => 'number',
      '#default_value' => $config->get('warning_threshhold'),
      '#weight' => 0,
      '#max' => 0.99,
      '#step' => 0.01
    ];
    $form['warning_mail'] = [
      '#title' => t('Notification that balance limits were crossed.'),
      '#type' => 'fieldset',
      '#tree' => 1,
      '#weight' => 15,
      'subject' => [
        '#title' => t('Subject'),
        '#type' => 'textfield',
        '#default_value' => $config->get('warning_mail.subject'),
        '#maxlength' => 180,
      ],
      'body' => [
        '#title' => t('Body'),
        '#description' => t("The [user] tokens, represent the email recipient."),
        '#type' => 'textarea',
        '#default_value' => $config->get('warning_mail.body'),
        '#rows' => 8,
      ],
      'tokens' => [
        '#theme' => 'token_tree_link',
        '#token_types' => ['current-user', 'user', 'transgression', ],
        '#global_types' => FALSE,
        '#weight' => 20
      ],
      '#states' => [
        'invisible' => [
          ':input[name="warning_threshhold"]' => ['value' => 0]
        ]
      ]
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('mcapi_limits.settings')
      ->set('warning_threshhold', $form_state->getValue('warning_threshhold'))
      ->set('warning_mail', $form_state->getValue('warning_mail'))
      ->save();
  }

}

==> mutual_credit-5.1.0.tar.gz: mutual_credit/modules/limits/src/Form/NotificationTemplatesForm.php <==
<?php

namespace Drupal\mcapi_limits\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
Use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\Core\Database\Connection;

/**
 * Form constructor for setting a wallet's limits.
 */
class NotificationTemplatesForm extends ConfigFormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'limit_notification_templates_form';
  }

  public function getEditableConfigNames() {
    return ['mcapi_limits.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('mcapi_limits.settings');
    $form['warning_threshhold'] = [
      '#title' => $this->t('Warning threshhold'),
      '#description' => $this->t('Fraction of the total limit to be reached before triggering a warning. Set to 0 for no warnings. 99 to warn at latest possible moment.'),
      '#type' => 'number',
      '#default_value' => $config->get('warning_threshhold'),
      '#weight' => 0,
      '#min' => 50,
      '#max' => 100,
      '#field_suffix' => '%',
      '#size' => 3
    ];
    $form['warning_mail'] = [
      '#title' => t('Notification that balance limits were crossed.'),
      '#type' => 'fieldset',
      '#tree' => 1,
      '#weight' => 15,
      'subject' => [
        '#title' => t('Subject'),
        '#type' => 'textfield',
        '#default_value' => $config->get('warning_mail.subject'),
        '#maxlength' => 180
      ],
      'body' => [
        '#title' => t('Body'),
        '#description' => t("The [user] tokens, represent the email recipient."),
        '#type' => 'textarea',
        '#default_value' => $config->get('warning_mail.body'),
        '#rows' => 8,
      ],
      'tokens' => [
        '#theme' => 'token_tree_link',
        '#token_types' => ['current-user', 'user', 'transgression', ],
        '#global_types' => FALSE,
        '#weight' => 20
      ],
      '#states' => [
        'invisible' => [
          ':input[name="warning_threshhold"]' => ['value' => 0]
        ]
      ]
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('mcapi_limits.settings')
      ->set('warning_threshhold', $form_state->getValue('warning_threshhold'))
      ->set('warning_mail', $form_state->getValue('warning_mail'))
      ->save();
  }

}
